@@ -30,6 +30,7 @@ class ParcelEventConst:
     CHECKING = 'checking'  # 上架
     CHECKED = 'checked'  # 揽收
     TRANSFER_INACTIVE = 'transfer_inactive'  # 提交召回
+    BULK_CHECKING = 'bulk_checking'  # 批量上架
 
     FROM_TO_MAP = {
         NEW_ADD: {
@@ -50,6 +51,12 @@ class ParcelEventConst:
             ],
             ParcelEventConstKey.TO_STATUS_KEY: ParcelStatus.CHECKING
         },
+        BULK_CHECKING: {
+            ParcelEventConstKey.FROM_STATUS_LIST_KEY: [
+                ParcelStatus.INIT
+            ],
+            ParcelEventConstKey.TO_STATUS_KEY: ParcelStatus.CHECKING
+        },
         CHECKED: {
             ParcelEventConstKey.FROM_STATUS_LIST_KEY: [
                 ParcelStatus.CHECKING
@@ -68,6 +75,7 @@ class ParcelEventConst:
         NEW_ADD: "包裹打包",
         CANCEL: "包裹取消打包",
         CHECKING: "包裹上架",
+        BULK_CHECKING: "批量上架",
         CHECKED: "包裹揽收",
         TRANSFER_INACTIVE: "包裹召回",
     }
@@ -86,7 +94,7 @@ class TransferStatus:
 
     TRANSFER_STAUTS_CHOICES = {
         ACTIVE: "已上架",
-        INACTIVE: "已找回",
+        INACTIVE: "已召回",
     }
 
 
